ShapeConstraintEvalError

Enum ShapeConstraintEvalError 

pub enum ShapeConstraintEvalError {
    MissingInput {
        input_idx: usize,
        input_count: usize,
    },
    AxisOutOfBounds {
        input_idx: usize,
        axis: usize,
        rank: usize,
    },
    Overflow,
    Underflow,
    DivisionByZero,
}
Typed reason that a symbolic shape constraint could not be evaluated.

Examples

use tenferro_runtime::ShapeConstraintEvalError;

let cause = ShapeConstraintEvalError::MissingInput {
    input_idx: 2,
    input_count: 1,
};
assert_eq!(
    cause.to_string(),
    "shape expression references input 2, but only 1 inputs were provided"
);

Variants



MissingInput

An expression referenced an input shape that was not supplied.

Fields

input_idx: usize

Referenced input index.

input_count: usize

Number of supplied input shapes.



AxisOutOfBounds

An expression referenced an axis outside the selected input’s rank.

Fields

input_idx: usize

Referenced input index.

axis: usize

Referenced axis.

rank: usize

Rank of the selected input.



Overflow

Checked dimension arithmetic overflowed usize.



Underflow

Checked dimension subtraction underflowed usize.



DivisionByZero

A floor-division divisor evaluated to zero.