BoxError

Type Alias BoxError 

pub type BoxError = Box<dyn StdError + Send + Sync + 'static>;
Boxed source used when a runtime registry or compiler subsystem crosses the runtime error boundary with a concrete error owned by another crate.

Aliased Type

pub struct BoxError(/* private fields */);