ExtensionCacheSelector

Enum ExtensionCacheSelector 

pub enum ExtensionCacheSelector {
    All,
    Family {
        family_id: &'static str,
    },
    Cache {
        family_id: &'static str,
        cache_name: &'static str,
    },
}
Selector used to inspect or clear extension cache entries.

Variants



All

Select every extension cache entry.



Family

Select every entry owned by an extension family.

Fields

family_id: &'static str


Cache

Select entries in one named cache for one extension family.

Fields

family_id: &'static str
cache_name: &'static str

Implementations

Source

impl ExtensionCacheSelector

pub fn matches(&self, key: &ExtensionCacheKey) -> bool

Return true when this selector includes key.

Examples
use tenferro_runtime::{ExtensionCacheKey, ExtensionCacheSelector};

let key = ExtensionCacheKey::new("example.identity.v1", "plans", 0);
assert!(ExtensionCacheSelector::Family {
    family_id: "example.identity.v1",
}.matches(&key));