GraphProgramLoweringShapeError

Enum GraphProgramLoweringShapeError 

pub enum GraphProgramLoweringShapeError {
    MissingOutput {
        op: &'static str,
        output_index: usize,
    },
    NonStatic {
        op: &'static str,
        output_index: usize,
        axis: usize,
        kind: &'static str,
    },
    InvalidDimExpr {
        op: &'static str,
        output_index: usize,
        axis: usize,
        source: DimExprEvalError,
    },
}
Error returned when a lowering view cannot resolve an exact output shape.

Examples

use tenferro_runtime::GraphProgramLoweringShapeError;

let err = GraphProgramLoweringShapeError::MissingOutput {
    op: "Example",
    output_index: 0,
};
assert!(err.to_string().contains("Example"));

Variants



MissingOutput

The instruction has no metadata for the requested output.

Fields

op: &'static str
output_index: usize


NonStatic

The instruction output has dynamic or unknown extent metadata.

Fields

op: &'static str
output_index: usize
axis: usize
kind: &'static str


InvalidDimExpr

Static shape evaluation failed for an exact dimension expression.

Fields

op: &'static str
output_index: usize
axis: usize
source: DimExprEvalError