GraphExecutorCacheStats

Struct GraphExecutorCacheStats 

pub struct GraphExecutorCacheStats {
    pub extensions: CacheStats,
    pub backend: CacheStats,
}
Stats for runtime caches owned by a graph executor.

retained_bytes fields are logical payload estimates, not process RSS.

Examples

use tenferro_runtime::{CacheStats, GraphExecutorCacheStats};

let stats = GraphExecutorCacheStats {
    extensions: CacheStats::empty(),
    backend: CacheStats::empty(),
};
assert_eq!(stats.extensions.entries, 0);

Fields

extensions: CacheStats

Generic extension runtime caches.

backend: CacheStats

Backend-specific runtime analysis cache.