#[non_exhaustive]pub enum ProgramBindingError {
InvalidTarget,
DTypeMismatch {
expected: DType,
actual: DType,
},
RankMismatch {
expected: usize,
actual: usize,
},
ExactExtentMismatch {
axis: usize,
expected: usize,
actual: usize,
},
UpperBoundExceeded {
axis: usize,
bound: usize,
actual: usize,
},
}Expand description
Tensor-binding validation failures detected during atomic freeze.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidTarget
A pending binding no longer names an external input.
DTypeMismatch
Tensor dtype differs from the input declaration.
RankMismatch
Tensor rank differs from the input declaration.
ExactExtentMismatch
A statically exact dimension differs from the input declaration.
Fields
UpperBoundExceeded
A bounded dimension exceeds the declared upper bound.