#[non_exhaustive]pub enum ProgramShapeRelation {
Equal,
LessEqual,
GreaterEqual,
}Expand description
Relation enforced between two symbolic dimension expressions.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Equal
Both expressions must evaluate to the same extent.
LessEqual
The left expression must not exceed the right expression.
GreaterEqual
The left expression must be at least the right expression.