#[non_exhaustive]pub enum ProgramStructuralError {
InvalidValueReference,
InvalidSsaOrder,
}Expand description
Internal structural validation failures detected during atomic freeze.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidValueReference
An operation references a value outside the frozen value table.
InvalidSsaOrder
An operation output is not strictly after all prior values.