pub struct ShapeGuard { /* private fields */ }Expand description
A backend-neutral symbolic-shape obligation.
Implementations
Sourceimpl ShapeGuard
impl ShapeGuard
Sourcepub fn new(relation: ProgramShapeRelation, lhs: DimExpr, rhs: DimExpr) -> Self
pub fn new(relation: ProgramShapeRelation, lhs: DimExpr, rhs: DimExpr) -> Self
Construct a shape guard.
Sourcepub const fn relation(&self) -> ProgramShapeRelation
pub const fn relation(&self) -> ProgramShapeRelation
Return the required relation.
Sourcepub const fn source_family(&self) -> Option<&'static str>
pub const fn source_family(&self) -> Option<&'static str>
Return the diagnostic family that introduced this guard, when known.
Diagnostic provenance does not participate in semantic equality or the semantic fingerprint.