pub enum Determinism {
Fast,
Reproducible,
}Expand description
Selects the planning and execution reproducibility policy.
Examples
use tenferro_runtime::Determinism;
assert_eq!(Determinism::Fast, Determinism::Fast);Variants
Fast
Prefer fast backend choices when multiple valid plans exist.
Reproducible
Prefer reproducible backend choices when multiple valid plans exist.