#[non_exhaustive]pub enum EngineExecutionContractError {
OutputResidencyMismatch {
instruction_index: usize,
output_slot: usize,
engine_id: EngineId,
storage_class: StorageClass,
backend_family: Option<&'static str>,
allocation_domain: Option<AllocationDomainId>,
},
}Expand description
Reports a runtime execution bridge that violated its output contract.
Examples
use tenferro_runtime::{EngineExecutionContractError, EngineId, StorageClass};
let error = EngineExecutionContractError::OutputResidencyMismatch {
instruction_index: 3,
output_slot: 7,
engine_id: EngineId::new("tenferro.cpu")?,
storage_class: StorageClass::new("tenferro.storage.host")?,
backend_family: Some("foreign-backend"),
allocation_domain: None,
};
assert!(error.to_string().contains("output slot 7"));Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
OutputResidencyMismatch
An executor returned a tensor not owned by its scheduled engine/storage.
Fields

storage_class: StorageClassStorage class selected by the prepared schedule.

allocation_domain: Option<AllocationDomainId>Physical allocation domain reported by the tensor.