#[non_exhaustive]pub enum ExecutionPolicyError {}Expand description
Reports invalid execution-policy configuration.
Phase 4 currently has no invalid public execution policy state, but the error type is part of the accepted runtime configuration contract.
Examples
use std::fmt::Debug;
use tenferro_runtime::ExecutionPolicyError;
fn requires_debug<T: Debug>() {}
requires_debug::<ExecutionPolicyError>();Trait Implementations
Sourceimpl Clone for ExecutionPolicyError
impl Clone for ExecutionPolicyError
Sourcefn clone(&self) -> ExecutionPolicyError
fn clone(&self) -> ExecutionPolicyError
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExecutionPolicyError
impl Debug for ExecutionPolicyError
Sourceimpl Display for ExecutionPolicyError
impl Display for ExecutionPolicyError
Sourceimpl Error for ExecutionPolicyError
impl Error for ExecutionPolicyError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl PartialEq for ExecutionPolicyError
impl PartialEq for ExecutionPolicyError
Sourcefn eq(&self, other: &ExecutionPolicyError) -> bool
fn eq(&self, other: &ExecutionPolicyError) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for ExecutionPolicyError
impl Eq for ExecutionPolicyError
impl StructuralPartialEq for ExecutionPolicyError