#[non_exhaustive]pub enum ExtensionModuleError {
ConflictingModule {
module_id: ExtensionModuleId,
},
ConflictingEngine {
module_id: ExtensionModuleId,
family_id: &'static str,
engine_id: EngineId,
},
PlanningConfigWithoutEngine {
module_id: ExtensionModuleId,
engine_id: EngineId,
},
PlanningConfigFamilyMismatch {
module_id: ExtensionModuleId,
engine_id: EngineId,
expected: &'static str,
actual: &'static str,
},
MissingPlanningConfig {
module_id: ExtensionModuleId,
engine_id: EngineId,
},
ConflictingPlanningConfig {
module_id: ExtensionModuleId,
engine_id: EngineId,
},
ConflictingCacheOwner {
module_id: ExtensionModuleId,
owner: CacheOwnerId,
},
}Expand description
Reports invalid extension module registration transactions.
Examples
use tenferro_runtime::{EngineId, ExtensionModuleError, ExtensionModuleId};
let error = ExtensionModuleError::MissingPlanningConfig {
module_id: ExtensionModuleId::new("tenferro.module.test")?,
engine_id: EngineId::new("tenferro.engine.test")?,
};
assert!(error.to_string().contains("planning config"));Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ConflictingModule
A distinct module is already installed at the same module ID.
Fields

module_id: ExtensionModuleIdConflicting module ID.
ConflictingEngine
A distinct extension engine is already registered for the same
(family, engine) key.
Fields

module_id: ExtensionModuleIdExtension module ID.
PlanningConfigWithoutEngine
A planning config was registered without exactly one matching engine.
PlanningConfigFamilyMismatch
Planning config family did not match the registered engine family.
Fields

module_id: ExtensionModuleIdExtension module ID.
MissingPlanningConfig
An engine was registered without its required planning config.
ConflictingPlanningConfig
A distinct planning config is already registered for the same engine.
ConflictingCacheOwner
A distinct cache owner is already registered for the same local owner ID.