#[non_exhaustive]pub enum InputIngressContractError {
ResidencyMismatch {
input_slot: usize,
ingress_engine_id: EngineId,
ingress_storage_class: StorageClass,
placement: Placement,
backend_family: Option<&'static str>,
allocation_domain: Option<AllocationDomainId>,
},
}Expand description
Reports a runtime input that violates a prepared ingress contract.
Examples
use tenferro_runtime::{EngineId, InputIngressContractError, StorageClass};
use tenferro_tensor::Placement;
let error = InputIngressContractError::ResidencyMismatch {
input_slot: 0,
ingress_engine_id: EngineId::new("tenferro.cpu")?,
ingress_storage_class: StorageClass::new("tenferro.storage.host")?,
placement: Placement::default(),
backend_family: Some("foreign-backend"),
allocation_domain: None,
};
assert!(error.to_string().contains("input slot 0"));Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ResidencyMismatch
A runtime input’s physical residency is incompatible with its prepared ingress.
Fields

ingress_storage_class: StorageClassStorage class selected as the prepared input ingress.

allocation_domain: Option<AllocationDomainId>Physical allocation domain reported by the input.