pub enum InputSignatureError {
ShapeStrideRankMismatch {
rank: usize,
stride_count: usize,
},
InvalidAlignmentClass {
alignment_log2: u8,
},
TensorMetadata {
input: usize,
source: Error,
},
}Expand description
Reports failures while building value-free input signatures.
Examples
use tenferro_runtime::{DType, InputSignatureEntry, LayoutClass};
use tenferro_tensor::Placement;
let error = InputSignatureEntry::new(
DType::F64,
[2_usize].into_iter().collect(),
Placement::default(),
LayoutClass::new("tenferro.layout.strided").unwrap(),
[1_isize, 2].into_iter().collect(),
None,
)
.unwrap_err();
assert!(matches!(error, tenferro_runtime::InputSignatureError::ShapeStrideRankMismatch { .. }));Variants
ShapeStrideRankMismatch
Shape rank and stride rank disagree.
InvalidAlignmentClass
The alignment class is outside the finite usize alignment lattice.
TensorMetadata
Tensor metadata could not be read for an input.