pub enum PlacementSpecialization {
None,
StorageClass,
Device,
}Expand description
Selects how much placement metadata enters a specialization key.
Examples
use tenferro_runtime::PlacementSpecialization;
assert_eq!(PlacementSpecialization::None, PlacementSpecialization::None);Variants
None
Do not specialize on placement.
StorageClass
Specialize only on the storage class derived from memory kind.
Device
Specialize on full device placement metadata.