pub enum PrepareCapability {
Prepared(PreparedOperationPlan),
NeedsSpecialization(SpecializationRequirements),
Unsupported(UnsupportedReason),
}Expand description
Result of asking a provider to prepare an operation.
Examples
use tenferro_runtime::{CoreCapabilityKind, PrepareCapability, UnsupportedReason};
let capability = PrepareCapability::Unsupported(UnsupportedReason::MissingCapability {
capability: CoreCapabilityKind::Elementwise,
});
assert!(matches!(capability, PrepareCapability::Unsupported { .. }));Variants
Prepared(PreparedOperationPlan)
Provider returned an immutable prepared operation.
NeedsSpecialization(SpecializationRequirements)
Provider requires a wider specialization before it can prepare.
Unsupported(UnsupportedReason)
Provider does not support this request.