ProviderContractError

Enum ProviderContractError 

pub enum ProviderContractError {
    WrongOperationFamily {
        expected: CoreCapabilityKind,
        operation: &'static str,
    },
    BindingMismatch {
        expected: Box<PreparedOperationBinding>,
        actual: Box<PreparedOperationBinding>,
    },
    ProjectionMismatch {
        expected: Box<SpecializationProjection>,
        actual: Box<SpecializationProjection>,
    },
    InvalidSpecialization {
        source: SpecializationError,
    },
    NonWideningSpecialization {
        previous: Box<SpecializationRequirements>,
        next: Box<SpecializationRequirements>,
    },
    SpecializationRetryLimitExceeded {
        attempts: usize,
        limit: usize,
    },
}
Reports provider violations of runtime preparation contracts.

Examples

use tenferro_runtime::{CoreCapabilityKind, ProviderContractError};

let error = ProviderContractError::WrongOperationFamily {
    expected: CoreCapabilityKind::Elementwise,
    operation: "dot_general",
};
assert!(error.to_string().contains("dot_general"));

Variants



WrongOperationFamily

A provider accepted a request from the wrong core operation family.

Fields

expected: CoreCapabilityKind

Expected core capability family.

operation: &'static str

Operation diagnostic name.



BindingMismatch

A prepared operation returned a different binding than requested.

Fields

expected: Box<PreparedOperationBinding>

Runtime-created binding requested from the provider.

actual: Box<PreparedOperationBinding>

Binding returned by the provider.



ProjectionMismatch

A prepared operation returned a different specialization projection.

Fields

expected: Box<SpecializationProjection>

Runtime-created projection requested from the provider.

actual: Box<SpecializationProjection>

Projection returned by the provider.



InvalidSpecialization

A provider returned an invalid specialization.

Fields

source: SpecializationError

Original specialization failure.



NonWideningSpecialization

A provider requested specialization that did not strictly widen the current requirements.

Fields

previous: Box<SpecializationRequirements>

Previous specialization requirements.

next: Box<SpecializationRequirements>

Provider-requested specialization requirements.



SpecializationRetryLimitExceeded

A provider exceeded the finite specialization retry bound.

Fields

attempts: usize

Number of redirect attempts observed.

limit: usize

Computed finite retry bound.