RegistrationKey

Enum RegistrationKey 

#[non_exhaustive]
pub enum RegistrationKey { Engine(EngineId), ExtensionEngine { family: &'static str, engine: EngineId, }, ExtensionPlanning { module: ExtensionModuleId, engine: EngineId, }, ExtensionCacheOwner { module: ExtensionModuleId, owner: CacheOwnerId, }, TransferProvider { source: TransferEndpoint, destination: TransferEndpoint, }, }
Identifies a runtime registration slot involved in a configuration conflict.

Examples

use tenferro_runtime::{EngineId, RegistrationKey};

let key = RegistrationKey::Engine(EngineId::new("tenferro.cpu")?);
assert!(format!("{key:?}").contains("tenferro.cpu"));

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Engine(EngineId)

A direct engine registration.



ExtensionEngine

An extension engine registration.

Fields

family: &'static str

Extension family.

engine: EngineId

Runtime engine.



ExtensionPlanning

An extension planning config registration.

Fields

module: ExtensionModuleId

Extension module.

engine: EngineId

Runtime engine.



ExtensionCacheOwner

An extension cache-owner registration.

Fields

module: ExtensionModuleId

Extension module.

owner: CacheOwnerId

Local cache owner.



TransferProvider

A transfer provider keyed by source and destination endpoints.

Fields

source: TransferEndpoint

Source endpoint.

destination: TransferEndpoint

Destination endpoint.