pub enum RuntimeStateError {
Poisoned {
lock: &'static str,
},
}Expand description
Runtime state failure shared by preparation and cache management.
Variants
Poisoned
A synchronization primitive was poisoned by a panic in another thread.