pub enum SubmitError {
PreAdmission {
source: Box<Error>,
inputs: Box<ExecutionInputs>,
},
}Expand description
A detached submission failed before ownership could be transferred to the in-flight worker.
Examples
use tenferro_runtime::{Error, runtime::{ExecutionInputs, SubmitError}};
let error = SubmitError::PreAdmission {
source: Box::new(Error::Internal("input rejected".into())),
inputs: Box::new(ExecutionInputs::new(Vec::new())?),
};
assert!(error.to_string().contains("before admission"));Variants
PreAdmission
Preparation/admission rejected the request. The exact input package is returned unchanged to the caller.
Implementations
Sourceimpl SubmitError
impl SubmitError
Sourcepub fn into_pre_admission(self) -> Option<(Error, ExecutionInputs)>
pub fn into_pre_admission(self) -> Option<(Error, ExecutionInputs)>
Recover the unchanged package from a pre-admission rejection.
Examples
use tenferro_runtime::{Error, runtime::{ExecutionInputs, SubmitError}};
let error = SubmitError::PreAdmission {
source: Box::new(Error::Internal("input rejected".into())),
inputs: Box::new(ExecutionInputs::new(Vec::new())?),
};
assert!(error.into_pre_admission().is_some());Trait Implementations
Sourceimpl Debug for SubmitError
impl Debug for SubmitError
Sourceimpl Display for SubmitError
impl Display for SubmitError
Sourceimpl Error for SubmitError
impl Error for SubmitError
Sourcefn source(&self) -> Option<&(dyn StdError + 'static)>
fn source(&self) -> Option<&(dyn StdError + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl From<SubmitError> for Error
impl From<SubmitError> for Error
Sourcefn from(error: SubmitError) -> Self
fn from(error: SubmitError) -> Self
Converts to this type from the input type.