#[non_exhaustive]pub enum TransferError {
MissingProvider {
source_endpoint: TransferEndpoint,
source_event_domain_id: EventDomainId,
destination_endpoint: TransferEndpoint,
destination_event_domain_id: EventDomainId,
},
ProviderContract {
source: TransferProviderContractError,
},
}Expand description
Typed runtime transfer setup failure.
Examples
use tenferro_runtime::TransferError;
fn is_missing_provider(error: &TransferError) -> bool {
matches!(error, TransferError::MissingProvider { .. })
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
MissingProvider
No provider was registered for the endpoint pair required by two concrete execution locations.
Fields

source_endpoint: TransferEndpointSource transfer endpoint.

source_event_domain_id: EventDomainIdSource event domain.

destination_endpoint: TransferEndpointDestination transfer endpoint.

destination_event_domain_id: EventDomainIdDestination event domain.
ProviderContract
A provider returned a tensor that violates the transfer request contract.
Fields

source: TransferProviderContractErrorTyped provider-contract violation.