TransferProviderContractError

Enum TransferProviderContractError 

#[non_exhaustive]
pub enum TransferProviderContractError { LogicalElementCount { source: Error, }, DTypeMismatch { expected: DType, actual: DType, }, ShapeMismatch { expected: Vec<usize>, actual: Vec<usize>, }, DestinationPlacementMismatch { destination_engine_id: EngineId, destination_storage_class: StorageClass, actual: Placement, }, DestinationResidencyMismatch { destination_engine_id: EngineId, destination_storage_class: StorageClass, actual_backend_family: Option<&'static str>, actual_allocation_domain: Option<AllocationDomainId>, }, InvalidBufferLength { expected: usize, actual: usize, }, }
Typed contract violation in a tensor returned by a transfer provider.

Examples

use tenferro_runtime::{DType, TransferProviderContractError};

let error = TransferProviderContractError::DTypeMismatch {
    expected: DType::F64,
    actual: DType::F32,
};
assert!(error.to_string().contains("dtype"));

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


LogicalElementCount

The logical source shape cannot be represented as an element count.

Fields

source: Error

Checked tensor shape-product failure.



DTypeMismatch

The returned tensor changed the source dtype.

Fields

expected: DType

Source dtype required by the request.

actual: DType

Dtype returned by the provider.



ShapeMismatch

The returned tensor changed the source shape.

Fields

expected: Vec<usize>

Source shape required by the request.

actual: Vec<usize>

Shape returned by the provider.



DestinationPlacementMismatch

The returned tensor placement is not accepted at the destination endpoint.

Fields

destination_engine_id: EngineId

Destination engine from the transfer request.

destination_storage_class: StorageClass

Destination storage class from the transfer request.

actual: Placement

Placement returned by the provider.



DestinationResidencyMismatch

The returned tensor has compatible metadata but is not owned by the destination engine’s backend or allocation domain.

Fields

destination_engine_id: EngineId

Destination engine from the transfer request.

destination_storage_class: StorageClass

Destination storage class from the transfer request.

actual_backend_family: Option<&'static str>

Physical backend family returned by the provider.

actual_allocation_domain: Option<AllocationDomainId>

Shared allocation domain returned by the provider.



InvalidBufferLength

The returned tensor’s buffer length does not match its shape.

Fields

expected: usize

Element count required by the returned shape.

actual: usize

Element count reported by the returned buffer.