#[non_exhaustive]pub enum UnsupportedReason {
MissingCapability {
capability: CoreCapabilityKind,
},
Operation {
operation: &'static str,
},
StorageClass {
storage_class: StorageClass,
},
}Expand description
Deterministic reason why a provider cannot prepare an operation.
Examples
use tenferro_runtime::{CoreCapabilityKind, UnsupportedReason};
let reason = UnsupportedReason::MissingCapability {
capability: CoreCapabilityKind::Elementwise,
};
assert!(reason.to_string().contains("Elementwise"));Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
MissingCapability
The runtime snapshot has no provider for this core capability.
Fields

capability: CoreCapabilityKindMissing core capability kind.
Operation
The named operation is unsupported by the selected provider.
StorageClass
The selected provider does not support the required storage class.
Fields

storage_class: StorageClassUnsupported storage class.