pub struct ExtensionModuleRegistrar<'a> { /* private fields */ }Expand description
Borrowed registrar for one extension module transaction.
Implementations
Sourceimpl ExtensionModuleRegistrar<'_>
impl ExtensionModuleRegistrar<'_>
Sourcepub fn register_engine(
&mut self,
engine: Arc<dyn ExtensionEngine>,
) -> Result<(), ExtensionModuleError>
pub fn register_engine( &mut self, engine: Arc<dyn ExtensionEngine>, ) -> Result<(), ExtensionModuleError>
Register one extension preparation engine.
Errors
Returns ExtensionModuleError::ConflictingEngine when a distinct
engine already occupies the same (family, engine) transaction key.
Sourcepub fn register_planning_config(
&mut self,
engine_id: EngineId,
config: Arc<dyn ExtensionPlanningConfig>,
) -> Result<(), ExtensionModuleError>
pub fn register_planning_config( &mut self, engine_id: EngineId, config: Arc<dyn ExtensionPlanningConfig>, ) -> Result<(), ExtensionModuleError>
Register the planning config for one extension engine.
Errors
Returns a typed ExtensionModuleError when the target engine is absent,
the config family is mismatched, or an unequal config is already present.
Sourcepub fn register_cache_owner(
&mut self,
id: CacheOwnerId,
owner: Arc<dyn RuntimeCacheOwner>,
) -> Result<(), ExtensionModuleError>
pub fn register_cache_owner( &mut self, id: CacheOwnerId, owner: Arc<dyn RuntimeCacheOwner>, ) -> Result<(), ExtensionModuleError>
Register a cache owner owned by this extension module.
Errors
Returns ExtensionModuleError::ConflictingCacheOwner when a distinct
owner already occupies the same local owner ID.