pub struct InputSignature { /* private fields */ }Expand description
Value-free signature of all tensor inputs for one prepare request.
Examples
use tenferro_runtime::InputSignature;
let signature = InputSignature::new(Vec::new());
assert!(signature.entries().is_empty());Implementations
Sourceimpl InputSignature
impl InputSignature
Sourcepub fn new(entries: Vec<InputSignatureEntry>) -> Self
pub fn new(entries: Vec<InputSignatureEntry>) -> Self
Build a signature from already prepared entries.
Examples
use tenferro_runtime::InputSignature;
let signature = InputSignature::new(Vec::new());
assert_eq!(signature.entries().len(), 0);Sourcepub fn from_reads(reads: &[TensorRead<'_>]) -> Result<Self, PrepareError>
pub fn from_reads(reads: &[TensorRead<'_>]) -> Result<Self, PrepareError>
Build a value-free signature from borrowed tensor reads.
Examples
use tenferro_runtime::{InputSignature, TensorRead, Tensor};
let tensor = Tensor::from_vec_col_major(vec![2], vec![1.0_f64, 2.0])?;
let signature = InputSignature::from_reads(&[TensorRead::from_tensor(&tensor)])?;
assert_eq!(signature.entries()[0].shape(), &[2]);Errors
Returns PrepareError::InputSignature with the original typed tensor
metadata error when shape, stride, or compactness metadata cannot be read.
Sourcepub fn entries(&self) -> &[InputSignatureEntry]
pub fn entries(&self) -> &[InputSignatureEntry]
Return the per-input entries.
Examples
use tenferro_runtime::InputSignature;
assert!(InputSignature::new(Vec::new()).entries().is_empty());Trait Implementations
Sourceimpl Clone for InputSignature
impl Clone for InputSignature
Sourcefn clone(&self) -> InputSignature
fn clone(&self) -> InputSignature
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InputSignature
impl Debug for InputSignature
Sourceimpl Hash for InputSignature
impl Hash for InputSignature
Sourceimpl PartialEq for InputSignature
impl PartialEq for InputSignature
Sourcefn eq(&self, other: &InputSignature) -> bool
fn eq(&self, other: &InputSignature) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for InputSignature
impl StructuralPartialEq for InputSignature