pub struct PreparedOperationBinding { /* private fields */ }Expand description
Runtime-created immutable binding for one prepared operation.
A1 has no public constructor. B0/C1 provide the runtime creation path.
Examples
use std::fmt::Debug;
use tenferro_runtime::PreparedOperationBinding;
fn requires_debug<T: Debug>() {}
requires_debug::<PreparedOperationBinding>();Implementations
Sourceimpl PreparedOperationBinding
impl PreparedOperationBinding
Sourcepub fn runtime_id(&self) -> RuntimeId
pub fn runtime_id(&self) -> RuntimeId
Return the runtime identity that created this binding.
Examples
use std::fmt::Debug;
use tenferro_runtime::PreparedOperationBinding;
fn requires_debug<T: Debug>() {}
requires_debug::<PreparedOperationBinding>();Sourcepub fn epoch(&self) -> RuntimeEpoch
pub fn epoch(&self) -> RuntimeEpoch
Return the immutable runtime epoch that created this binding.
Examples
use std::fmt::Debug;
use tenferro_runtime::PreparedOperationBinding;
fn requires_debug<T: Debug>() {}
requires_debug::<PreparedOperationBinding>();Sourcepub fn engine_id(&self) -> &EngineId
pub fn engine_id(&self) -> &EngineId
Return the selected engine identifier.
Examples
use std::fmt::Debug;
use tenferro_runtime::PreparedOperationBinding;
fn requires_debug<T: Debug>() {}
requires_debug::<PreparedOperationBinding>();Sourcepub fn registration_identity(&self) -> RegistrationIdentity
pub fn registration_identity(&self) -> RegistrationIdentity
Return the runtime-local engine registration identity.
Examples
use std::fmt::Debug;
use tenferro_runtime::PreparedOperationBinding;
fn requires_debug<T: Debug>() {}
requires_debug::<PreparedOperationBinding>();Sourcepub fn context_identity(&self) -> ExecutionContextIdentity
pub fn context_identity(&self) -> ExecutionContextIdentity
Return the execution-context type identity.
Examples
use std::fmt::Debug;
use tenferro_runtime::PreparedOperationBinding;
fn requires_debug<T: Debug>() {}
requires_debug::<PreparedOperationBinding>();Sourcepub fn hardware_class(&self) -> &HardwareClassId
pub fn hardware_class(&self) -> &HardwareClassId
Return the selected hardware-class identifier.
Examples
use std::fmt::Debug;
use tenferro_runtime::PreparedOperationBinding;
fn requires_debug<T: Debug>() {}
requires_debug::<PreparedOperationBinding>();Trait Implementations
Sourceimpl Clone for PreparedOperationBinding
impl Clone for PreparedOperationBinding
Sourcefn clone(&self) -> PreparedOperationBinding
fn clone(&self) -> PreparedOperationBinding
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PreparedOperationBinding
impl Debug for PreparedOperationBinding
Sourceimpl Hash for PreparedOperationBinding
impl Hash for PreparedOperationBinding
Sourceimpl PartialEq for PreparedOperationBinding
impl PartialEq for PreparedOperationBinding
Sourcefn eq(&self, other: &PreparedOperationBinding) -> bool
fn eq(&self, other: &PreparedOperationBinding) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for PreparedOperationBinding
impl StructuralPartialEq for PreparedOperationBinding