pub struct ProviderId(/* private fields */);Expand description
Validated namespaced identity of a runtime provider.
A provider ID identifies the implementation namespace in the runtime control plane. It is deliberately distinct from tensor placement metadata.
Examples
use tenferro_runtime::ProviderId;
assert_eq!(ProviderId::new("tenferro.cpu")?.as_str(), "tenferro.cpu");Implementations
Sourceimpl ProviderId
impl ProviderId
Sourcepub fn new(value: impl Into<Arc<str>>) -> Result<Self, IdentityError>
pub fn new(value: impl Into<Arc<str>>) -> Result<Self, IdentityError>
Validate a lowercase ASCII namespaced provider identifier.
Errors
Returns IdentityError with IdentityKind::Provider when value
does not match the lowercase ASCII namespaced identifier grammar.
Examples
use tenferro_runtime::ProviderId;
assert!(ProviderId::new("tenferro.cuda").is_ok());Trait Implementations
Sourceimpl Clone for ProviderId
impl Clone for ProviderId
Sourcefn clone(&self) -> ProviderId
fn clone(&self) -> ProviderId
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProviderId
impl Debug for ProviderId
Sourceimpl Hash for ProviderId
impl Hash for ProviderId
Sourceimpl Ord for ProviderId
impl Ord for ProviderId
Sourcefn cmp(&self, other: &ProviderId) -> Ordering
fn cmp(&self, other: &ProviderId) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ProviderId
impl PartialEq for ProviderId
Sourcefn eq(&self, other: &ProviderId) -> bool
fn eq(&self, other: &ProviderId) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ProviderId
impl PartialOrd for ProviderId
impl Eq for ProviderId
impl StructuralPartialEq for ProviderId