pub struct RuntimeConfigSnapshot { /* private fields */ }Expand description
Immutable runtime configuration snapshot.
A snapshot is readable after later reconfiguration because the runtime
publishes a new Arc instead of mutating existing slots.
Examples
use tenferro_runtime::RuntimeConfigBuilder;
let runtime = RuntimeConfigBuilder::new().build()?;
let snapshot = runtime.snapshot()?;
assert_eq!(snapshot.engine_count(), 0);Implementations
Sourceimpl RuntimeConfigSnapshot
impl RuntimeConfigSnapshot
Sourcepub fn runtime_id(&self) -> RuntimeId
pub fn runtime_id(&self) -> RuntimeId
Return the runtime identity that published this snapshot.
Sourcepub fn epoch(&self) -> RuntimeEpoch
pub fn epoch(&self) -> RuntimeEpoch
Return the epoch for this immutable snapshot.
Sourcepub fn execution_policy(&self) -> &ExecutionPolicy
pub fn execution_policy(&self) -> &ExecutionPolicy
Return the execution policy captured by this snapshot.
Sourcepub fn engine_count(&self) -> usize
pub fn engine_count(&self) -> usize
Return the number of direct engine slots.
Sourcepub fn extension_module_count(&self) -> usize
pub fn extension_module_count(&self) -> usize
Return the number of installed extension modules.
Sourcepub fn transfer_provider_count(&self) -> usize
pub fn transfer_provider_count(&self) -> usize
Return the number of registered transfer providers.
Sourcepub fn engine(&self, id: &EngineId) -> Option<EngineSnapshotView<'_>>
pub fn engine(&self, id: &EngineId) -> Option<EngineSnapshotView<'_>>
Return an immutable view of a registered engine slot.