pub struct RuntimeEpoch(/* private fields */);Expand description
Opaque monotonically increasing configuration epoch for one runtime.
A new epoch is published when a runtime reconfiguration changes its execution snapshot; prepared work from an older epoch is rejected.
Examples
use std::fmt::Debug;
use tenferro_runtime::RuntimeEpoch;
fn requires_debug<T: Debug>() {}
requires_debug::<RuntimeEpoch>();Trait Implementations
Sourceimpl Clone for RuntimeEpoch
impl Clone for RuntimeEpoch
Sourcefn clone(&self) -> RuntimeEpoch
fn clone(&self) -> RuntimeEpoch
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RuntimeEpoch
impl Debug for RuntimeEpoch
Sourceimpl Hash for RuntimeEpoch
impl Hash for RuntimeEpoch
Sourceimpl Ord for RuntimeEpoch
impl Ord for RuntimeEpoch
Sourcefn cmp(&self, other: &RuntimeEpoch) -> Ordering
fn cmp(&self, other: &RuntimeEpoch) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for RuntimeEpoch
impl PartialEq for RuntimeEpoch
Sourcefn eq(&self, other: &RuntimeEpoch) -> bool
fn eq(&self, other: &RuntimeEpoch) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for RuntimeEpoch
impl PartialOrd for RuntimeEpoch
impl Copy for RuntimeEpoch
impl Eq for RuntimeEpoch
impl StructuralPartialEq for RuntimeEpoch