ExtensionPlanningConfig

Trait ExtensionPlanningConfig 

pub trait ExtensionPlanningConfig:
    Any
    + Debug
    + Send
    + Sync
    + 'static {
    // Required methods
    fn family_id(&self) -> &'static str;
    fn as_any(&self) -> &dyn Any;
    fn payload_hash(&self, state: &mut dyn Hasher);
    fn payload_eq(&self, other: &dyn ExtensionPlanningConfig) -> bool;
    fn retained_bytes(&self) -> usize;
}
Snapshot-retained extension planning configuration.

The family id follows the existing extension &'static str contract used by ExtensionOp::family_id.

Required Methods

fn family_id(&self) -> &'static str

Return the extension family id this configuration belongs to.

fn as_any(&self) -> &dyn Any

Return this config as Any for typed equality checks.

fn payload_hash(&self, state: &mut dyn Hasher)

Hash only the family-specific payload.

fn payload_eq(&self, other: &dyn ExtensionPlanningConfig) -> bool

Compare only the family-specific payload.

fn retained_bytes(&self) -> usize

Return logical retained bytes owned by this config.

Implementors