pub struct SymDimConversionError {
pub tensor_id: u64,
}Expand description
A symbolic dimension referenced a tensor that is not present in the conversion map supplied by the graph builder.
Fields
tensor_id: u64Identifier of the missing symbolic tensor.