TensorValue

Enum TensorValue 

pub enum TensorValue {
    Tensor(Arc<Tensor>),
    View(TensorOwnedView),
}
Owned tensor value that can be compact or a lazy view.

TensorValue is the owned counterpart to TensorRead. It is suitable for storing eager results that should remain lazy until an operation actually requires compact materialized storage.

Variants

Implementations

Source

impl TensorValue

pub fn from_tensor(tensor: Tensor) -> TensorValue

pub fn from_tensor_arc(tensor: Arc<Tensor>) -> TensorValue

pub fn as_tensor_arc(&self) -> Option<&Arc<Tensor>>

pub fn dtype(&self) -> DType

pub fn shape(&self) -> &[usize]

pub fn tensor_read(&self) -> TensorRead<'_>

pub fn to_tensor(&self) -> Result<Tensor, Error>

Materialize this tensor value into an owned compact tensor.

Compact tensor values are cloned. Lazy host views are materialized. Backend-backed views return an explicit error instead of panicking.

Examples
use tenferro_tensor::{Tensor, TensorValue};

let value = TensorValue::from_tensor(Tensor::from_vec_col_major(
    vec![2],
    vec![1.0_f64, 2.0],
).unwrap());
let tensor = value.to_tensor()?;
assert_eq!(tensor.shape(), &[2]);
pub fn transpose_view( &self, axes: impl AsRef<[usize]>, ) -> Result<TensorValue, Error>

pub fn reshape_view(&self, shape: &[usize]) -> Result<TensorValue, Error>

pub fn slice_view(&self, config: &SliceConfig) -> Result<TensorValue, Error>

pub fn broadcast_in_dim_view( &self, shape: &[usize], dims: &[usize], ) -> Result<TensorValue, Error>