apply_expanded_graph

Function apply_expanded_graph 

pub fn apply_expanded_graph(
    inputs: &[&TracedTensor],
    output_metas: Vec<(DType, Vec<SymDim>)>,
    build: impl FnOnce(&mut GraphBuilder<StdTensorOp>, &[ValueRef<StdTensorOp>]) -> Result<Vec<usize>>,
) -> Result<Vec<TracedTensor>>
Apply an extension-provided lowering as ordinary traced graph operations.

This is for extension crates whose operation can be expanded at graph-build time. It preserves the same parent graph and metadata merging behavior as apply, but does not insert a StdTensorOp::Extension carrier.