pub enum ExtensionCacheSelector {
All,
Family {
family_id: &'static str,
},
Cache {
family_id: &'static str,
cache_name: &'static str,
},
}Expand description
Selector used to inspect or clear extension cache entries.
Variants
All
Select every extension cache entry.
Family
Select every entry owned by an extension family.
Cache
Select entries in one named cache for one extension family.
Implementations
Sourceimpl ExtensionCacheSelector
impl ExtensionCacheSelector
Sourcepub fn matches(&self, key: &ExtensionCacheKey) -> bool
pub fn matches(&self, key: &ExtensionCacheKey) -> bool
Return true when this selector includes key.
Examples
use tenferro_runtime::{ExtensionCacheKey, ExtensionCacheSelector};
let key = ExtensionCacheKey::new("example.identity.v1", "plans", 0);
assert!(ExtensionCacheSelector::Family {
family_id: "example.identity.v1",
}.matches(&key));Trait Implementations
Sourceimpl Clone for ExtensionCacheSelector
impl Clone for ExtensionCacheSelector
Sourcefn clone(&self) -> ExtensionCacheSelector
fn clone(&self) -> ExtensionCacheSelector
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtensionCacheSelector
impl Debug for ExtensionCacheSelector
Sourceimpl Hash for ExtensionCacheSelector
impl Hash for ExtensionCacheSelector
Sourceimpl PartialEq for ExtensionCacheSelector
impl PartialEq for ExtensionCacheSelector
impl Copy for ExtensionCacheSelector
impl Eq for ExtensionCacheSelector
impl StructuralPartialEq for ExtensionCacheSelector