pub struct ProgramValueMetadata { /* private fields */ }Expand description
Dtype and ordered symbolic extents of one semantic SSA value.
Implementations
Sourceimpl ProgramValueMetadata
impl ProgramValueMetadata
Sourcepub fn new(dtype: DType, shape: impl IntoIterator<Item = DimExpr>) -> Self
pub fn new(dtype: DType, shape: impl IntoIterator<Item = DimExpr>) -> Self
Construct value metadata from a dtype and symbolic shape.
Sourcepub fn from_extents(
dtype: DType,
shape: impl IntoIterator<Item = ShapeExtent<DimExpr>>,
) -> Self
pub fn from_extents( dtype: DType, shape: impl IntoIterator<Item = ShapeExtent<DimExpr>>, ) -> Self
Construct metadata with explicit exact, bounded, or unknown extents.
Sourcepub fn shape(&self) -> &[ShapeExtent<DimExpr>]
pub fn shape(&self) -> &[ShapeExtent<DimExpr>]
Borrow the ordered symbolic extents without allocation.