SemanticProgram

Struct SemanticProgram 

pub struct SemanticProgram { /* private fields */ }
Immutable backend-neutral semantic SSA program.

Implementations

Source

impl SemanticProgram

pub fn inputs(&self) -> &[ProgramValue]

Borrow ordered external inputs.

pub fn outputs(&self) -> &[ProgramValue]

Borrow ordered program outputs.

pub fn operations( &self, ) -> impl ExactSizeIterator<Item = SemanticOperationView<'_>> + '_

Iterate over operations in semantic order.

pub fn value_metadata( &self, value: ProgramValue, ) -> Result<&ProgramValueMetadata, ProgramQueryError>

Borrow metadata for a value owned by this program.

Errors

Returns ProgramQueryError::ForeignValue for a foreign token.

pub fn shape_guards(&self) -> &[ShapeGuard]

Borrow all symbolic guards in semantic operation order.

pub const fn semantic_fingerprint(&self) -> SemanticFingerprint

Return the cached normalized structural fingerprint.

pub fn semantic_eq(&self, other: &Self) -> bool

Compare exact normalized semantics after the compact fingerprint check.