pub struct SemanticProgram { /* private fields */ }Expand description
Immutable backend-neutral semantic SSA program.
Implementations
Sourceimpl SemanticProgram
impl SemanticProgram
Sourcepub fn inputs(&self) -> &[ProgramValue]
pub fn inputs(&self) -> &[ProgramValue]
Borrow ordered external inputs.
Sourcepub fn outputs(&self) -> &[ProgramValue]
pub fn outputs(&self) -> &[ProgramValue]
Borrow ordered program outputs.
Sourcepub fn operations(
&self,
) -> impl ExactSizeIterator<Item = SemanticOperationView<'_>> + '_
pub fn operations( &self, ) -> impl ExactSizeIterator<Item = SemanticOperationView<'_>> + '_
Iterate over operations in semantic order.
Sourcepub fn value_metadata(
&self,
value: ProgramValue,
) -> Result<&ProgramValueMetadata, ProgramQueryError>
pub fn value_metadata( &self, value: ProgramValue, ) -> Result<&ProgramValueMetadata, ProgramQueryError>
Borrow metadata for a value owned by this program.
Errors
Returns ProgramQueryError::ForeignValue for a foreign token.
Sourcepub fn shape_guards(&self) -> &[ShapeGuard]
pub fn shape_guards(&self) -> &[ShapeGuard]
Borrow all symbolic guards in semantic operation order.
Sourcepub const fn semantic_fingerprint(&self) -> SemanticFingerprint
pub const fn semantic_fingerprint(&self) -> SemanticFingerprint
Return the cached normalized structural fingerprint.
Sourcepub fn semantic_eq(&self, other: &Self) -> bool
pub fn semantic_eq(&self, other: &Self) -> bool
Compare exact normalized semantics after the compact fingerprint check.