pub struct EventDomainId { /* private fields */ }Expand description
Provenance-qualified identity of one frozen direct-engine event domain.
An event domain is identified by the runtime that owns it, the immutable configuration epoch that published it, and the frozen registration identity of the direct engine slot. It is not a reusable slot number.
Examples
use tenferro_runtime::EventDomainId;
fn inspect(domain: EventDomainId) {
let _runtime = domain.runtime_id();
let _epoch = domain.epoch();
let _registration = domain.registration_identity();
}Implementations
Sourceimpl EventDomainId
impl EventDomainId
Sourcepub const fn runtime_id(self) -> RuntimeId
pub const fn runtime_id(self) -> RuntimeId
Return the runtime that owns this event domain.
Examples
use tenferro_runtime::EventDomainId;
fn inspect(domain: EventDomainId) {
let _runtime = domain.runtime_id();
}Sourcepub const fn epoch(self) -> RuntimeEpoch
pub const fn epoch(self) -> RuntimeEpoch
Return the immutable configuration epoch that published this domain.
Examples
use tenferro_runtime::EventDomainId;
fn inspect(domain: EventDomainId) {
let _epoch = domain.epoch();
}Sourcepub const fn registration_identity(self) -> RegistrationIdentity
pub const fn registration_identity(self) -> RegistrationIdentity
Return the frozen direct-engine registration identity for this domain.
Examples
use tenferro_runtime::EventDomainId;
fn inspect(domain: EventDomainId) {
let _registration = domain.registration_identity();
}Trait Implementations
Sourceimpl Clone for EventDomainId
impl Clone for EventDomainId
Sourcefn clone(&self) -> EventDomainId
fn clone(&self) -> EventDomainId
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EventDomainId
impl Debug for EventDomainId
Sourceimpl Hash for EventDomainId
impl Hash for EventDomainId
Sourceimpl Ord for EventDomainId
impl Ord for EventDomainId
Sourcefn cmp(&self, other: &EventDomainId) -> Ordering
fn cmp(&self, other: &EventDomainId) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for EventDomainId
impl PartialEq for EventDomainId
Sourcefn eq(&self, other: &EventDomainId) -> bool
fn eq(&self, other: &EventDomainId) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for EventDomainId
impl PartialOrd for EventDomainId
impl Copy for EventDomainId
impl Eq for EventDomainId
impl StructuralPartialEq for EventDomainId